use anyhow::Result;
use clap::Clap;
use log::info;

/// Delete a message queue
#[derive(Clap, Debug)]
pub struct Unlink {
    /// Id of the queue
    #[clap(
        long,
        short,
        required_unless_present_any = &["key"],
        conflicts_with = "key"
    )]
    id: Option<i32>,
    /// Key of the queue
    #[clap(long, short, required_unless_present_any = &["id"], conflicts_with = "id")]
    key: Option<i32>,
}

impl Unlink {
    pub fn run(&self) -> Result<()> {
        if let Some(id) = self.id {
            sysvmq::unlink_id(id)?;

            info!("Removed message queue with id: {}", id);
        } else if let Some(key) = self.key {
            sysvmq::unlink_key(key)?;

            info!("Removed message queue key: {}", key);
        }

        Ok(())
    }
}
